@@ -104,7 +104,7 @@ sub download_zip {
     }
     warn sprintf "%s\tZIP? '%s' folder ok\n", __PACKAGE__, $folder;
 
-    my $nppv = $ENV{W32MNPP_FORCE_VER} || 'v8.1.4';
+    my $nppv = $ENV{W32MNPP_FORCE_VER} || 'v8.5.2';
     warn sprintf "%s\tWanting to download zip %s\n", __PACKAGE__, $nppv;
     my %url = (
         'v8.1.4' => {
@@ -131,6 +131,28 @@ sub download_zip {
                 name  => 'npp.8.3.3.portable.zip',
             },
         },
+        'v8.4.8' => {
+            64 => {
+                #https => 'https://download.notepad-plus-plus.org/repository/8.x/8.4.8/npp.8.4.8.portable.x64.zip',
+                http  => 'http://download.notepad-plus-plus.org/repository/8.x/8.4.8/npp.8.4.8.portable.x64.zip',
+                name  => 'npp.8.4.8.portable.x64.zip',
+            },
+            32 => {
+                #https => 'https://download.notepad-plus-plus.org/repository/8.x/8.4.8/npp.8.4.8.portable.zip',
+                http  => 'http://download.notepad-plus-plus.org/repository/8.x/8.4.8/npp.8.4.8.portable.zip',
+                name  => 'npp.8.4.8.portable.zip',
+            },
+        },
+        'v8.5.2' => {
+            64 => {
+                http  => 'http://download.notepad-plus-plus.org/repository/8.x/8.5.2/npp.8.5.2.portable.x64.zip',
+                name  => 'npp.8.5.2.portable.x64.zip',
+            },
+            32 => {
+                http  => 'http://download.notepad-plus-plus.org/repository/8.x/8.5.2/npp.8.5.2.portable.zip',
+                name  => 'npp.8.5.2.portable.zip',
+            },
+        },
     );
     die "don't know the URL for ", ($nppv//'<undef>') unless exists $url{$nppv};
 
