@@ -77,6 +77,7 @@ our %NPPMSG = (
     'NPPM_ALLOCATECMDID'                                         => ((1024 + 1000) + 81),
     'NPPM_ALLOCATEMARKER'                                        => ((1024 + 1000) + 82),
     'NPPM_ALLOCATESUPPORTED'                                     => ((1024 + 1000) + 80),
+    'NPPM_CREATELEXER'                                           => ((1024 + 1000) + 110),  # v8.4.3
     'NPPM_CREATESCINTILLAHANDLE'                                 => ((1024 + 1000) + 20),
     'NPPM_DECODESCI'                                             => ((1024 + 1000) + 27),
     'NPPM_DESTROYSCINTILLAHANDLE'                                => ((1024 + 1000) + 21),
@@ -94,11 +95,13 @@ our %NPPMSG = (
     'NPPM_DOOPEN'                                                => ((1024 + 1000) + 77),
     'NPPM_ENCODESCI'                                             => ((1024 + 1000) + 26),
     'NPPM_GETAPPDATAPLUGINSALLOWED'                              => ((1024 + 1000) + 87),
+    'NPPM_GETBOOKMARKID'                                         => ((1024 + 1000) + 111),
     'NPPM_GETBUFFERENCODING'                                     => ((1024 + 1000) + 66),
     'NPPM_GETBUFFERFORMAT'                                       => ((1024 + 1000) + 68),
     'NPPM_GETBUFFERIDFROMPOS'                                    => ((1024 + 1000) + 59),
     'NPPM_GETBUFFERLANGTYPE'                                     => ((1024 + 1000) + 64),
     'NPPM_GETCURRENTBUFFERID'                                    => ((1024 + 1000) + 60),
+    'NPPM_GETCURRENTCMDLINE'                                     => ((1024 + 1000) + 109),
     'NPPM_GETCURRENTCOLUMN'                                      => ((1024 + 3000) + 9),
     'NPPM_GETCURRENTDIRECTORY'                                   => ((1024 + 3000) + 2),
     'NPPM_GETCURRENTDOCINDEX'                                    => ((1024 + 1000) + 23),
@@ -113,6 +116,8 @@ our %NPPMSG = (
     'NPPM_GETEDITORDEFAULTBACKGROUNDCOLOR'                       => ((1024 + 1000) + 91),
     'NPPM_GETEDITORDEFAULTFOREGROUNDCOLOR'                       => ((1024 + 1000) + 90),
     'NPPM_GETENABLETHEMETEXTUREFUNC'                             => ((1024 + 1000) + 45),
+    'NPPM_GETENABLETHEMETEXTUREFUNC_DEPRECATED'                  => ((1024 + 1000) + 45),   # v8.4.x
+    'NPPM_GETEXTERNALLEXERAUTOINDENTMODE'                        => ((1024 + 1000) + 103),  # v8.3.3
     'NPPM_GETEXTPART'                                            => ((1024 + 3000) + 5),
     'NPPM_GETFILENAME'                                           => ((1024 + 3000) + 3),
     'NPPM_GETFILENAMEATCURSOR'                                   => ((1024 + 3000) + 11),
@@ -144,6 +149,7 @@ our %NPPMSG = (
     'NPPM_HIDETABBAR'                                            => ((1024 + 1000) + 51),
     'NPPM_HIDETOOLBAR'                                           => ((1024 + 1000) + 70),
     'NPPM_ISAUTOINDENTON'                                        => ((1024 + 1000) + 105),  # v8.3.3
+    'NPPM_ISDARKMODEENABLED'                                     => ((1024 + 1000) + 107),  # v8.4.1
     'NPPM_ISDOCSWITCHERSHOWN'                                    => ((1024 + 1000) + 86),
     'NPPM_ISDOCLISTSHOWN'                                        => ((1024 + 1000) + 86),	# v8.1.3
     'NPPM_ISMENUHIDDEN'                                          => ((1024 + 1000) + 73),
@@ -170,6 +176,7 @@ our %NPPMSG = (
     'NPPM_SETBUFFERLANGTYPE'                                     => ((1024 + 1000) + 65),
     'NPPM_SETCURRENTLANGTYPE'                                    => ((1024 + 1000) + 6),
     'NPPM_SETEDITORBORDEREDGE'                                   => ((1024 + 1000) + 93),
+    'NPPM_SETEXTERNALLEXERAUTOINDENTMODE'                        => ((1024 + 1000) + 104),  # v8.3.3
     'NPPM_SETLINENUMBERWIDTHMODE'                                => ((1024 + 1000) + 99), # v7.9.2
     'NPPM_SETMENUITEMCHECK'                                      => ((1024 + 1000) + 40),
     'NPPM_SETSMOOTHFONT'                                         => ((1024 + 1000) + 92),
@@ -373,14 +380,15 @@ our %LANGTYPE = (
     'L_DIFF'                                                     => 33,
     'L_ERLANG'                                                   => 71,
     'L_ESCRIPT'                                                  => 72,
-    'L_EXTERNAL'                                                 => 86,
     'L_FLASH'                                                    => 27,
     'L_FORTH'                                                    => 73,
     'L_FORTRAN'                                                  => 25,
     'L_FORTRAN_77'                                               => 59,
     'L_FREEBASIC'                                                => 69,
+    'L_GDSCRIPT'                                                 => 88, # v8.5.1
     'L_GUI4CLI'                                                  => 51,
     'L_HASKELL'                                                  => 45,
+    'L_HOLLYWOOD'                                                => 89, # v8.5.2
     'L_HTML'                                                     => 8,
     'L_IHEX'                                                     => 62,
     'L_INI'                                                      => 13,
@@ -389,6 +397,7 @@ our %LANGTYPE = (
     'L_JAVASCRIPT'                                               => 58,
     'L_JS'                                                       => 19,
     'L_JSON'                                                     => 57,
+    'L_JSON5'                                                    => 86, # v8.4.9
     'L_JSP'                                                      => 55,
     'L_KIX'                                                      => 39,
     'L_LATEX'                                                    => 74,
@@ -397,8 +406,9 @@ our %LANGTYPE = (
     'L_MAKEFILE'                                                 => 10,
     'L_MATLAB'                                                   => 44,
     'L_MMIXAL'                                                   => 75,
-    'L_NIMROD'                                                   => 76,
+    'L_MSSQL'                                                    => 87, # v8.5.1
     'L_NIM'                                                      => 76, # v8
+    'L_NIMROD'                                                   => 76,
     'L_NNCRONTAB'                                                => 77,
     'L_NSIS'                                                     => 28,
     'L_OBJC'                                                     => 5,
@@ -437,6 +447,7 @@ our %LANGTYPE = (
     'L_VISUALPROLOG'                                             => 84,
     'L_XML'                                                      => 9,
     'L_YAML'                                                     => 49,
+    'L_EXTERNAL'                                                 => 90,
 );
 
 =item %LINENUMWIDTH
@@ -478,6 +489,7 @@ our %WINVER = (
     'WV_VISTA'                                                   => 10,
     'WV_W2K'                                                     => 6,
     'WV_WIN10'                                                   => 14,
+    'WV_WIN11'                                                   => 15,
     'WV_WIN32S'                                                  => 1,
     'WV_WIN7'                                                    => 11,
     'WV_WIN8'                                                    => 12,
@@ -496,6 +508,7 @@ I'm not sure it's really useful, but it's still privided.
 
 our %WINPLATFORM = (
     # enum Platform
+    'PF_ARM64'                                                   => 4,
     'PF_IA64'                                                    => 3,
     'PF_UNKNOWN'                                                 => 0,
     'PF_X64'                                                     => 2,
@@ -611,7 +624,10 @@ our %NOTIFICATION = (
     'NPPN_BEFORESHUTDOWN'                                        => (1000 + 19),
     'NPPN_BUFFERACTIVATED'                                       => (1000 + 10),
     'NPPN_CANCELSHUTDOWN'                                        => (1000 + 20),
+    'NPPN_CMDLINEPLUGINMSG'                                      => (1000 + 28),    # v8.4.2
+    'NPPN_DARKMODECHANGED'                                       => (1000 + 27),    # v8.4.1
     'NPPN_DOCORDERCHANGED'                                       => (1000 + 17),
+    'NPPN_EXTERNALLEXERBUFFER'                                   => (1000 + 29),    # v8.5
     'NPPN_FILEBEFORECLOSE'                                       => (1000 + 3),
     'NPPN_FILEBEFOREDELETE'                                      => (1000 + 24),
     'NPPN_FILEBEFORELOAD'                                        => (1000 + 14),
@@ -692,13 +708,18 @@ our %NPPIDM = (
     'IDM_CMDLINEARGUMENTS'                                       => ((40000  + 7000)  + 10),
     'IDM_CONFUPDATERPROXY'                                       => ((40000  + 7000)  + 9),
     'IDM_DEBUGINFO'                                              => ((40000  + 7000)  + 12),
+    'IDM_DOCLIST_COPYNAMES'                                      => ((40000 + 3500) + 3),		# v8.2.1
+    'IDM_DOCLIST_COPYPATHS'                                      => ((40000 + 3500) + 4),		# v8.2.1
     'IDM_DOCLIST_FILESCLOSE'                                     => ((40000 + 3500) + 1),		# v8.1.3
     'IDM_DOCLIST_FILESCLOSEOTHERS'                               => ((40000 + 3500) + 2),		# v8.1.3
+    'IDM_DROPLIST_LIST'                                          => (14000 + 1),		# v8.4.3
+    'IDM_DROPLIST_MRU_FIRST'                                     => (14000 + 20),		# v8.4.3
     'IDM_EDIT'                                                   => (40000 + 2000),
     'IDM_EDIT_AUTOCOMPLETE'                                      => (50000 + 0),
     'IDM_EDIT_AUTOCOMPLETE_CURRENTFILE'                          => (50000 + 1),
     'IDM_EDIT_AUTOCOMPLETE_PATH'                                 => (50000 + 6),
     'IDM_EDIT_BEGINENDSELECT'                                    => ((40000 + 2000) + 20),
+    'IDM_EDIT_BEGINENDSELECT_COLUMNMODE'                         => ((40000 + 2000) + 89),		# v8.5
     'IDM_EDIT_BLANKLINEABOVECURRENT'                             => ((40000 + 2000) + 57),
     'IDM_EDIT_BLANKLINEBELOWCURRENT'                             => ((40000 + 2000) + 58),
     'IDM_EDIT_BLOCK_COMMENT'                                     => ((40000 + 2000) + 22),
@@ -711,6 +732,8 @@ our %NPPIDM = (
     'IDM_EDIT_COLUMNMODE'                                        => ((40000 + 2000) + 34),
     'IDM_EDIT_COLUMNMODETIP'                                     => ((40000 + 2000) + 37),
     'IDM_EDIT_COPY'                                              => ((40000 + 2000) + 2),
+    'IDM_EDIT_COPY_ALL_NAMES'                                    => ((40000 + 2000) + 87),		# v8.2.1
+    'IDM_EDIT_COPY_ALL_PATHS'                                    => ((40000 + 2000) + 88),		# v8.2.1
     'IDM_EDIT_COPY_BINARY'                                       => ((40000 + 2000) + 48),
     'IDM_EDIT_COPY_LINK'                                         => ((40000 + 2000) + 82),  # v7.9.2
     'IDM_EDIT_CURRENTDIRTOCLIP'                                  => ((40000 + 2000) + 31),
@@ -722,7 +745,9 @@ our %NPPIDM = (
     'IDM_EDIT_FILENAMETOCLIP'                                    => ((40000 + 2000) + 30),
     'IDM_EDIT_FULLPATHTOCLIP'                                    => ((40000 + 2000) + 29),
     'IDM_EDIT_FUNCCALLTIP'                                       => (50000 + 2),
-    'IDM_EDIT_INSERT_DATETIME_CUSTOMIZED'                        => ((40000 + 2000) + 86),	# v8.1.5?
+    'IDM_EDIT_FUNCCALLTIP_NEXT'                                  => (50000 + 11),		# v8.4.5
+    'IDM_EDIT_FUNCCALLTIP_PREVIOUS'                              => (50000 + 10),		# v8.4.5
+    'IDM_EDIT_INSERT_DATETIME_CUSTOMIZED'                        => ((40000 + 2000) + 86),	# v8.1.5
     'IDM_EDIT_INSERT_DATETIME_LONG'                              => ((40000 + 2000) + 85),	# v8.1.4
     'IDM_EDIT_INSERT_DATETIME_SHORT'                             => ((40000 + 2000) + 84),	# v8.1.4
     'IDM_EDIT_INS_TAB'                                           => ((40000 + 2000) + 8),
@@ -965,6 +990,7 @@ our %NPPIDM = (
     'IDM_LANG_TEXT'                                              => ((40000 + 6000) + 16),
     'IDM_LANG_TXT2TAGS'                                          => ((40000 + 6000) + 82),
     'IDM_LANG_TYPESCRIPT'                                        => ((40000 + 6000) + 84),	# v8.1.4
+    'IDM_LANG_UDLCOLLECTION_PROJECT_SITE'                        => ((40000 + 6000) + 301),	# v8.1.9.3
     'IDM_LANG_USER'                                              => ((40000 + 6000) + 180),
     'IDM_LANG_USER_DLG'                                          => ((40000 + 6000) + 250),
     'IDM_LANG_USER_LIMIT'                                        => ((40000 + 6000) + 210),
@@ -1080,7 +1106,7 @@ our %NPPIDM = (
     'IDM_VIEW_CLONE_TO_ANOTHER_VIEW'                             => 10002,
     'IDM_VIEW_CURLINE_HILITING'                                  => ((40000 + 4000) + 21),
     'IDM_VIEW_DISTRACTIONFREE'                                   => ((40000 + 4000) + 11),	# v8.0
-    'IDM_VIEW_DOCCHANGEMARGIN'                                   => ((40000 + 4000) + 45),
+    'IDM_VIEW_DOCCHANGEMARGIN'                                   => ((40000 + 4000) + 45),	# removed v8.4.6
     'IDM_VIEW_DOCLIST'                                           => ((40000 + 4000) + 70),	# v8.1.3
     'IDM_VIEW_DOC_MAP'                                           => ((40000 + 4000) + 80),
     'IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN'                            => ((40000 + 4000) + 38),
@@ -1096,6 +1122,7 @@ our %NPPIDM = (
     'IDM_VIEW_FILEBROWSER'                                       => ((40000 + 4000) + 85),
     'IDM_VIEW_FILESWITCHER_PANEL'                                => ((40000 + 4000) + 70),	# removed v8.1.3, but still supported in previous revs
     'IDM_VIEW_FOLD'                                              => ((40000 + 4000) + 50),
+    'IDM_VIEW_FOLDALL'                                           => ((40000 + 4000) + 10), # v8.4.2
     'IDM_VIEW_FOLDERMAGIN'                                       => ((40000 + 4000) + 14),
     'IDM_VIEW_FOLDERMAGIN_ARROW'                                 => ((40000 + 4000) + 16),
     'IDM_VIEW_FOLDERMAGIN_BOX'                                   => ((40000 + 4000) + 18),
@@ -1153,19 +1180,26 @@ our %NPPIDM = (
     'IDM_VIEW_TAB7'                                              => ((40000 + 4000) + 92),
     'IDM_VIEW_TAB8'                                              => ((40000 + 4000) + 93),
     'IDM_VIEW_TAB9'                                              => ((40000 + 4000) + 94),
+    'IDM_VIEW_TAB_COLOUR_1'                                      => ((40000 + 4000) + 111),		# v8.4.6
+    'IDM_VIEW_TAB_COLOUR_2'                                      => ((40000 + 4000) + 112),		# v8.4.6
+    'IDM_VIEW_TAB_COLOUR_3'                                      => ((40000 + 4000) + 113),		# v8.4.6
+    'IDM_VIEW_TAB_COLOUR_4'                                      => ((40000 + 4000) + 114),		# v8.4.6
+    'IDM_VIEW_TAB_COLOUR_5'                                      => ((40000 + 4000) + 115),		# v8.4.6
+    'IDM_VIEW_TAB_COLOUR_NONE'                                   => ((40000 + 4000) + 110),		# v8.4.6
     'IDM_VIEW_TAB_MOVEBACKWARD'                                  => ((40000 + 4000) + 99),
     'IDM_VIEW_TAB_MOVEFORWARD'                                   => ((40000 + 4000) + 98),
     'IDM_VIEW_TAB_NEXT'                                          => ((40000 + 4000) + 95),
     'IDM_VIEW_TAB_PREV'                                          => ((40000 + 4000) + 96),
     'IDM_VIEW_TAB_SPACE'                                         => ((40000 + 4000) + 25),
-    'IDM_VIEW_TOGGLE_FOLDALL'                                    => ((40000 + 4000) + 10),
-    'IDM_VIEW_TOGGLE_UNFOLDALL'                                  => ((40000 + 4000) + 29),
+    'IDM_VIEW_TOGGLE_FOLDALL'                                    => ((40000 + 4000) + 10), # removed v8.4.2
+    'IDM_VIEW_TOGGLE_UNFOLDALL'                                  => ((40000 + 4000) + 29), # removed v8.4.2
     'IDM_VIEW_TOOLBAR_ENLARGE'                                   => ((40000 + 4000) + 3),
     'IDM_VIEW_TOOLBAR_ENLARGE_SET2'                              => ((40000 + 4000) + 28),	# v8.0
     'IDM_VIEW_TOOLBAR_REDUCE'                                    => ((40000 + 4000) + 2),
     'IDM_VIEW_TOOLBAR_REDUCE_SET2'                               => ((40000 + 4000) + 27),	# v8.0
     'IDM_VIEW_TOOLBAR_STANDARD'                                  => ((40000 + 4000) + 4),
     'IDM_VIEW_UNFOLD'                                            => ((40000 + 4000) + 60),
+    'IDM_VIEW_UNFOLDALL'                                         => ((40000 + 4000) + 29),  # v8.4.2
     'IDM_VIEW_UNFOLD_1'                                          => (((40000 + 4000) + 60) + 1),
     'IDM_VIEW_UNFOLD_2'                                          => (((40000 + 4000) + 60) + 2),
     'IDM_VIEW_UNFOLD_3'                                          => (((40000 + 4000) + 60) + 3),
@@ -1181,6 +1215,21 @@ our %NPPIDM = (
     'IDM_VIEW_ZOOMOUT'                                           => ((40000 + 4000) + 24),
     'IDM_VIEW_ZOOMRESTORE'                                       => ((40000 + 4000) + 33),
     'IDM_WIKIFAQ'                                                => ((40000  + 7000)  + 7),
+    'IDM_WINDOW_COPY_NAME'                                       => ((11000 + 59) + 1),     # v8.3.2
+    'IDM_WINDOW_COPY_PATH'                                       => ((11000 + 59) + 2),     # v8.3.2
+    'IDM_WINDOW_MRU_FIRST'                                       => (11000 + 20),     # v8.3.2
+    'IDM_WINDOW_MRU_LIMIT'                                       => (11000 + 59),     # v8.3.2, changed v8.4.3
+    'IDM_WINDOW_SORT_FN_ASC'                                     => (11000 + 2),     # v8.3.2
+    'IDM_WINDOW_SORT_FN_DSC'                                     => (11000 + 3),     # v8.3.2
+    'IDM_WINDOW_SORT_FP_ASC'                                     => (11000 + 4),     # v8.3.2
+    'IDM_WINDOW_SORT_FP_DSC'                                     => (11000 + 5),     # v8.3.2
+    'IDM_WINDOW_SORT_FS_ASC'                                     => (11000 + 8),     # v8.3.2
+    'IDM_WINDOW_SORT_FS_DSC'                                     => (11000 + 9),     # v8.3.2
+    'IDM_WINDOW_SORT_FT_ASC'                                     => (11000 + 6),     # v8.3.2
+    'IDM_WINDOW_SORT_FT_DSC'                                     => (11000 + 7),     # v8.3.2
+    'IDM_WINDOW_WINDOWS'                                         => (11000 + 1),     # v8.3.2
+    'IDR_DROPLIST_MENU'                                          => 14000,      # v8.4.3
+    'IDR_WINDOWS_MENU'                                           => 11000,     # v8.3.2
 );
 
 =head2 OTHER USEFUL ENUMERATIONS
@@ -1259,9 +1308,9 @@ our %BUFFERENCODING = (
 
 =item %MACROSTATUS
 
-These are the values returned by 
-L<notepad-E<gt>getCurrentMacroStatus|Win32::Mechanize::NotepadPlusPlus::Notepad/getCurrentMacroStatus> 
-This hash provides a two way map: so its keys include both the string names (with the integers as values) 
+These are the values returned by
+L<notepad-E<gt>getCurrentMacroStatus|Win32::Mechanize::NotepadPlusPlus::Notepad/getCurrentMacroStatus>
+This hash provides a two way map: so its keys include both the string names (with the integers as values)
 and the integers (with the string names as values).
 
     Name                    | Integer       | Description
