@@ -1,4 +1,4 @@
-# auto-converted from src/menuCmdID.h at Fri Sep 10 09:49:00 2021
+# auto-converted from src/menuCmdID.h at Thu Jan  5 11:57:51 2023
 package Win32::Mechanize::NotepadPlusPlus::__npp_idm;
 
 use warnings;
@@ -14,8 +14,12 @@ our %nppidm_dummyhash = (
     'IDM_CMDLINEARGUMENTS'                                       => ((40000  + 7000)  + 10),
     'IDM_CONFUPDATERPROXY'                                       => ((40000  + 7000)  + 9),
     'IDM_DEBUGINFO'                                              => ((40000  + 7000)  + 12),
+    'IDM_DOCLIST_COPYNAMES'                                      => ((40000 + 3500) + 3),
+    'IDM_DOCLIST_COPYPATHS'                                      => ((40000 + 3500) + 4),
     'IDM_DOCLIST_FILESCLOSE'                                     => ((40000 + 3500) + 1),
     'IDM_DOCLIST_FILESCLOSEOTHERS'                               => ((40000 + 3500) + 2),
+    'IDM_DROPLIST_LIST'                                          => (14000 + 1),
+    'IDM_DROPLIST_MRU_FIRST'                                     => (14000 + 20),
     'IDM_EDIT'                                                   => (40000 + 2000),
     'IDM_EDIT_AUTOCOMPLETE'                                      => (50000 + 0),
     'IDM_EDIT_AUTOCOMPLETE_CURRENTFILE'                          => (50000 + 1),
@@ -33,6 +37,8 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_COLUMNMODE'                                        => ((40000 + 2000) + 34),
     'IDM_EDIT_COLUMNMODETIP'                                     => ((40000 + 2000) + 37),
     'IDM_EDIT_COPY'                                              => ((40000 + 2000) + 2),
+    'IDM_EDIT_COPY_ALL_NAMES'                                    => ((40000 + 2000) + 87),
+    'IDM_EDIT_COPY_ALL_PATHS'                                    => ((40000 + 2000) + 88),
     'IDM_EDIT_COPY_BINARY'                                       => ((40000 + 2000) + 48),
     'IDM_EDIT_COPY_LINK'                                         => ((40000 + 2000) + 82),
     'IDM_EDIT_CURRENTDIRTOCLIP'                                  => ((40000 + 2000) + 31),
@@ -44,6 +50,8 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_FILENAMETOCLIP'                                    => ((40000 + 2000) + 30),
     'IDM_EDIT_FULLPATHTOCLIP'                                    => ((40000 + 2000) + 29),
     'IDM_EDIT_FUNCCALLTIP'                                       => (50000 + 2),
+    'IDM_EDIT_FUNCCALLTIP_NEXT'                                  => (50000 + 11),
+    'IDM_EDIT_FUNCCALLTIP_PREVIOUS'                              => (50000 + 10),
     'IDM_EDIT_INSERT_DATETIME_CUSTOMIZED'                        => ((40000 + 2000) + 86),
     'IDM_EDIT_INSERT_DATETIME_LONG'                              => ((40000 + 2000) + 85),
     'IDM_EDIT_INSERT_DATETIME_SHORT'                             => ((40000 + 2000) + 84),
@@ -278,6 +286,7 @@ our %nppidm_dummyhash = (
     'IDM_LANG_TEXT'                                              => ((40000 + 6000) + 16),
     'IDM_LANG_TXT2TAGS'                                          => ((40000 + 6000) + 82),
     'IDM_LANG_TYPESCRIPT'                                        => ((40000 + 6000) + 84),
+    'IDM_LANG_UDLCOLLECTION_PROJECT_SITE'                        => ((40000 + 6000) + 301),
     'IDM_LANG_USER'                                              => ((40000 + 6000) + 180),
     'IDM_LANG_USER_DLG'                                          => ((40000 + 6000) + 250),
     'IDM_LANG_USER_LIMIT'                                        => ((40000 + 6000) + 210),
@@ -391,7 +400,6 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_CLONE_TO_ANOTHER_VIEW'                             => 10002,
     'IDM_VIEW_CURLINE_HILITING'                                  => ((40000 + 4000) + 21),
     'IDM_VIEW_DISTRACTIONFREE'                                   => ((40000 + 4000) + 11),
-    'IDM_VIEW_DOCCHANGEMARGIN'                                   => ((40000 + 4000) + 45),
     'IDM_VIEW_DOCLIST'                                           => ((40000 + 4000) + 70),
     'IDM_VIEW_DOC_MAP'                                           => ((40000 + 4000) + 80),
     'IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN'                            => ((40000 + 4000) + 38),
@@ -403,6 +411,7 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_EOL'                                               => ((40000 + 4000) + 26),
     'IDM_VIEW_FILEBROWSER'                                       => ((40000 + 4000) + 85),
     'IDM_VIEW_FOLD'                                              => ((40000 + 4000) + 50),
+    'IDM_VIEW_FOLDALL'                                           => ((40000 + 4000) + 10),
     'IDM_VIEW_FOLDERMAGIN'                                       => ((40000 + 4000) + 14),
     'IDM_VIEW_FOLDERMAGIN_ARROW'                                 => ((40000 + 4000) + 16),
     'IDM_VIEW_FOLDERMAGIN_BOX'                                   => ((40000 + 4000) + 18),
@@ -460,19 +469,24 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_TAB7'                                              => ((40000 + 4000) + 92),
     'IDM_VIEW_TAB8'                                              => ((40000 + 4000) + 93),
     'IDM_VIEW_TAB9'                                              => ((40000 + 4000) + 94),
+    'IDM_VIEW_TAB_COLOUR_1'                                      => ((40000 + 4000) + 111),
+    'IDM_VIEW_TAB_COLOUR_2'                                      => ((40000 + 4000) + 112),
+    'IDM_VIEW_TAB_COLOUR_3'                                      => ((40000 + 4000) + 113),
+    'IDM_VIEW_TAB_COLOUR_4'                                      => ((40000 + 4000) + 114),
+    'IDM_VIEW_TAB_COLOUR_5'                                      => ((40000 + 4000) + 115),
+    'IDM_VIEW_TAB_COLOUR_NONE'                                   => ((40000 + 4000) + 110),
     'IDM_VIEW_TAB_MOVEBACKWARD'                                  => ((40000 + 4000) + 99),
     'IDM_VIEW_TAB_MOVEFORWARD'                                   => ((40000 + 4000) + 98),
     'IDM_VIEW_TAB_NEXT'                                          => ((40000 + 4000) + 95),
     'IDM_VIEW_TAB_PREV'                                          => ((40000 + 4000) + 96),
     'IDM_VIEW_TAB_SPACE'                                         => ((40000 + 4000) + 25),
-    'IDM_VIEW_TOGGLE_FOLDALL'                                    => ((40000 + 4000) + 10),
-    'IDM_VIEW_TOGGLE_UNFOLDALL'                                  => ((40000 + 4000) + 29),
     'IDM_VIEW_TOOLBAR_ENLARGE'                                   => ((40000 + 4000) + 3),
     'IDM_VIEW_TOOLBAR_ENLARGE_SET2'                              => ((40000 + 4000) + 28),
     'IDM_VIEW_TOOLBAR_REDUCE'                                    => ((40000 + 4000) + 2),
     'IDM_VIEW_TOOLBAR_REDUCE_SET2'                               => ((40000 + 4000) + 27),
     'IDM_VIEW_TOOLBAR_STANDARD'                                  => ((40000 + 4000) + 4),
     'IDM_VIEW_UNFOLD'                                            => ((40000 + 4000) + 60),
+    'IDM_VIEW_UNFOLDALL'                                         => ((40000 + 4000) + 29),
     'IDM_VIEW_UNFOLD_1'                                          => (((40000 + 4000) + 60) + 1),
     'IDM_VIEW_UNFOLD_2'                                          => (((40000 + 4000) + 60) + 2),
     'IDM_VIEW_UNFOLD_3'                                          => (((40000 + 4000) + 60) + 3),
@@ -488,5 +502,20 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_ZOOMOUT'                                           => ((40000 + 4000) + 24),
     'IDM_VIEW_ZOOMRESTORE'                                       => ((40000 + 4000) + 33),
     'IDM_WIKIFAQ'                                                => ((40000  + 7000)  + 7),
+    'IDM_WINDOW_COPY_NAME'                                       => ((11000 + 59) + 1),
+    'IDM_WINDOW_COPY_PATH'                                       => ((11000 + 59) + 2),
+    'IDM_WINDOW_MRU_FIRST'                                       => (11000 + 20),
+    'IDM_WINDOW_MRU_LIMIT'                                       => (11000 + 59),
+    'IDM_WINDOW_SORT_FN_ASC'                                     => (11000 + 2),
+    'IDM_WINDOW_SORT_FN_DSC'                                     => (11000 + 3),
+    'IDM_WINDOW_SORT_FP_ASC'                                     => (11000 + 4),
+    'IDM_WINDOW_SORT_FP_DSC'                                     => (11000 + 5),
+    'IDM_WINDOW_SORT_FS_ASC'                                     => (11000 + 8),
+    'IDM_WINDOW_SORT_FS_DSC'                                     => (11000 + 9),
+    'IDM_WINDOW_SORT_FT_ASC'                                     => (11000 + 6),
+    'IDM_WINDOW_SORT_FT_DSC'                                     => (11000 + 7),
+    'IDM_WINDOW_WINDOWS'                                         => (11000 + 1),
+    'IDR_DROPLIST_MENU'                                          => 14000,
+    'IDR_WINDOWS_MENU'                                           => 11000,
 );
 1;
