@@ -1,4 +1,4 @@
-# auto-converted from src/Notepad_plus_msgs.h at Fri Sep 10 09:49:00 2021
+# auto-converted from src/Notepad_plus_msgs.h at Thu Jan  5 11:57:50 2023
 package Win32::Mechanize::NotepadPlusPlus::Notepad::Messages;
 
 use warnings;
@@ -12,6 +12,7 @@ our %nppm_dummyhash = (
     'CURRENT_COLUMN'                                             => 9,
     'CURRENT_DIRECTORY'                                          => 2,
     'CURRENT_LINE'                                               => 8,
+    'CURRENT_LINESTR'                                            => 12,
     'CURRENT_WORD'                                               => 6,
     'DOCSTATUS_BUFFERDIRTY'                                      => 2,
     'DOCSTATUS_READONLY'                                         => 1,
@@ -120,6 +121,7 @@ our %nppm_dummyhash = (
     'NPPM_ALLOCATECMDID'                                         => ((1024 + 1000) + 81),
     'NPPM_ALLOCATEMARKER'                                        => ((1024 + 1000) + 82),
     'NPPM_ALLOCATESUPPORTED'                                     => ((1024 + 1000) + 80),
+    'NPPM_CREATELEXER'                                           => ((1024 + 1000) + 110),
     'NPPM_CREATESCINTILLAHANDLE'                                 => ((1024 + 1000) + 20),
     'NPPM_DECODESCI'                                             => ((1024 + 1000) + 27),
     'NPPM_DESTROYSCINTILLAHANDLE'                                => ((1024 + 1000) + 21),
@@ -130,27 +132,34 @@ our %nppm_dummyhash = (
     'NPPM_DMMSHOW'                                               => ((1024 + 1000) + 30),
     'NPPM_DMMUPDATEDISPINFO'                                     => ((1024 + 1000) + 32),
     'NPPM_DMMVIEWOTHERTAB'                                       => ((1024 + 1000) + 35),
-    'NPPM_DOCLISTDISABLECOLUMN'                                  => ((1024 + 1000) + 89),
+    'NPPM_DOCLISTDISABLEEXTCOLUMN'                               => ((1024 + 1000) + 89),
+    'NPPM_DOCLISTDISABLEPATHCOLUMN'                              => ((1024 + 1000) + 102),
     'NPPM_DOOPEN'                                                => ((1024 + 1000) + 77),
     'NPPM_ENCODESCI'                                             => ((1024 + 1000) + 26),
     'NPPM_GETAPPDATAPLUGINSALLOWED'                              => ((1024 + 1000) + 87),
+    'NPPM_GETBOOKMARKID'                                         => ((1024 + 1000) + 111),
     'NPPM_GETBUFFERENCODING'                                     => ((1024 + 1000) + 66),
     'NPPM_GETBUFFERFORMAT'                                       => ((1024 + 1000) + 68),
     'NPPM_GETBUFFERIDFROMPOS'                                    => ((1024 + 1000) + 59),
     'NPPM_GETBUFFERLANGTYPE'                                     => ((1024 + 1000) + 64),
     'NPPM_GETCURRENTBUFFERID'                                    => ((1024 + 1000) + 60),
+    'NPPM_GETCURRENTCMDLINE'                                     => ((1024 + 1000) + 109),
     'NPPM_GETCURRENTCOLUMN'                                      => ((1024 + 3000) + 9),
     'NPPM_GETCURRENTDIRECTORY'                                   => ((1024 + 3000) + 2),
     'NPPM_GETCURRENTDOCINDEX'                                    => ((1024 + 1000) + 23),
     'NPPM_GETCURRENTLANGTYPE'                                    => ((1024 + 1000) + 5),
     'NPPM_GETCURRENTLINE'                                        => ((1024 + 3000) + 8),
+    'NPPM_GETCURRENTLINESTR'                                     => ((1024 + 3000) + 12),
+    'NPPM_GETCURRENTMACROSTATUS'                                 => ((1024 + 1000) + 106),
     'NPPM_GETCURRENTNATIVELANGENCODING'                          => ((1024 + 1000) + 79),
     'NPPM_GETCURRENTSCINTILLA'                                   => ((1024 + 1000) + 4),
     'NPPM_GETCURRENTVIEW'                                        => ((1024 + 1000) + 88),
     'NPPM_GETCURRENTWORD'                                        => ((1024 + 3000) + 6),
+    'NPPM_GETDARKMODECOLORS'                                     => ((1024 + 1000) + 108),
     'NPPM_GETEDITORDEFAULTBACKGROUNDCOLOR'                       => ((1024 + 1000) + 91),
     'NPPM_GETEDITORDEFAULTFOREGROUNDCOLOR'                       => ((1024 + 1000) + 90),
-    'NPPM_GETENABLETHEMETEXTUREFUNC'                             => ((1024 + 1000) + 45),
+    'NPPM_GETENABLETHEMETEXTUREFUNC_DEPRECATED'                  => ((1024 + 1000) + 45),
+    'NPPM_GETEXTERNALLEXERAUTOINDENTMODE'                        => ((1024 + 1000) + 103),
     'NPPM_GETEXTPART'                                            => ((1024 + 3000) + 5),
     'NPPM_GETFILENAME'                                           => ((1024 + 3000) + 3),
     'NPPM_GETFILENAMEATCURSOR'                                   => ((1024 + 3000) + 11),
@@ -181,6 +190,8 @@ our %nppm_dummyhash = (
     'NPPM_HIDESTATUSBAR'                                         => ((1024 + 1000) + 74),
     'NPPM_HIDETABBAR'                                            => ((1024 + 1000) + 51),
     'NPPM_HIDETOOLBAR'                                           => ((1024 + 1000) + 70),
+    'NPPM_ISAUTOINDENTON'                                        => ((1024 + 1000) + 105),
+    'NPPM_ISDARKMODEENABLED'                                     => ((1024 + 1000) + 107),
     'NPPM_ISDOCLISTSHOWN'                                        => ((1024 + 1000) + 86),
     'NPPM_ISMENUHIDDEN'                                          => ((1024 + 1000) + 73),
     'NPPM_ISSTATUSBARHIDDEN'                                     => ((1024 + 1000) + 75),
@@ -206,6 +217,7 @@ our %nppm_dummyhash = (
     'NPPM_SETBUFFERLANGTYPE'                                     => ((1024 + 1000) + 65),
     'NPPM_SETCURRENTLANGTYPE'                                    => ((1024 + 1000) + 6),
     'NPPM_SETEDITORBORDEREDGE'                                   => ((1024 + 1000) + 93),
+    'NPPM_SETEXTERNALLEXERAUTOINDENTMODE'                        => ((1024 + 1000) + 104),
     'NPPM_SETLINENUMBERWIDTHMODE'                                => ((1024 + 1000) + 99),
     'NPPM_SETMENUITEMCHECK'                                      => ((1024 + 1000) + 40),
     'NPPM_SETSMOOTHFONT'                                         => ((1024 + 1000) + 92),
@@ -216,6 +228,8 @@ our %nppm_dummyhash = (
     'NPPN_BEFORESHUTDOWN'                                        => (1000 + 19),
     'NPPN_BUFFERACTIVATED'                                       => (1000 + 10),
     'NPPN_CANCELSHUTDOWN'                                        => (1000 + 20),
+    'NPPN_CMDLINEPLUGINMSG'                                      => (1000 + 28),
+    'NPPN_DARKMODECHANGED'                                       => (1000 + 27),
     'NPPN_DOCORDERCHANGED'                                       => (1000 + 17),
     'NPPN_FILEBEFORECLOSE'                                       => (1000 + 3),
     'NPPN_FILEBEFOREDELETE'                                      => (1000 + 24),
@@ -243,6 +257,7 @@ our %nppm_dummyhash = (
     'NPPPLUGINMENU'                                              => 0,
     'NPP_DIRECTORY'                                              => 7,
     'NPP_FULL_FILE_PATH'                                         => 10,
+    'PF_ARM64'                                                   => 4,
     'PF_IA64'                                                    => 3,
     'PF_UNKNOWN'                                                 => 0,
     'PF_X64'                                                     => 2,
@@ -267,6 +282,7 @@ our %nppm_dummyhash = (
     'WV_VISTA'                                                   => 10,
     'WV_W2K'                                                     => 6,
     'WV_WIN10'                                                   => 14,
+    'WV_WIN11'                                                   => 15,
     'WV_WIN32S'                                                  => 1,
     'WV_WIN7'                                                    => 11,
     'WV_WIN8'                                                    => 12,
