@@ -1,4 +1,4 @@
-# auto-converted from src/Scintilla.h at Fri Sep 10 09:49:00 2021
+# auto-converted from src/Scintilla.h at Thu Jan  5 11:57:51 2023
 package Win32::Mechanize::NotepadPlusPlus::Editor::Messages;
 
 use warnings;
@@ -14,6 +14,7 @@ our %scimsg_dummyhash = (
     'ANNOTATION_STANDARD'                                        => 1,
     'CARETSTYLE_BLOCK'                                           => 2,
     'CARETSTYLE_BLOCK_AFTER'                                     => 0x100,
+    'CARETSTYLE_CURSES'                                          => 0x20,
     'CARETSTYLE_INS_MASK'                                        => 0xF,
     'CARETSTYLE_INVISIBLE'                                       => 0,
     'CARETSTYLE_LINE'                                            => 1,
@@ -27,16 +28,33 @@ our %scimsg_dummyhash = (
     'EDGE_LINE'                                                  => 1,
     'EDGE_MULTILINE'                                             => 3,
     'EDGE_NONE'                                                  => 0,
-    'EOLANNOTATION_BOXED'                                        => 2,
-    'EOLANNOTATION_HIDDEN'                                       => 0,
-    'EOLANNOTATION_STANDARD'                                     => 1,
+    'EOLANNOTATION_ANGLES'                                       => 0x122,
+    'EOLANNOTATION_ANGLE_CIRCLE'                                 => 0x102,
+    'EOLANNOTATION_ANGLE_FLAT'                                   => 0x112,
+    'EOLANNOTATION_BOXED'                                        => 0x2,
+    'EOLANNOTATION_CIRCLE_ANGLE'                                 => 0x120,
+    'EOLANNOTATION_CIRCLE_FLAT'                                  => 0x110,
+    'EOLANNOTATION_FLATS'                                        => 0x111,
+    'EOLANNOTATION_FLAT_ANGLE'                                   => 0x121,
+    'EOLANNOTATION_FLAT_CIRCLE'                                  => 0x101,
+    'EOLANNOTATION_HIDDEN'                                       => 0x0,
+    'EOLANNOTATION_STADIUM'                                      => 0x100,
+    'EOLANNOTATION_STANDARD'                                     => 0x1,
     'INDIC0_MASK'                                                => 0x20,
     'INDIC1_MASK'                                                => 0x40,
     'INDIC2_MASK'                                                => 0x80,
     'INDICATOR_CONTAINER'                                        => 8,
+    'INDICATOR_HISTORY_MODIFIED_DELETION'                        => 41,
+    'INDICATOR_HISTORY_MODIFIED_INSERTION'                       => 40,
+    'INDICATOR_HISTORY_REVERTED_TO_MODIFIED_DELETION'            => 43,
+    'INDICATOR_HISTORY_REVERTED_TO_MODIFIED_INSERTION'           => 42,
+    'INDICATOR_HISTORY_REVERTED_TO_ORIGIN_DELETION'              => 37,
+    'INDICATOR_HISTORY_REVERTED_TO_ORIGIN_INSERTION'             => 36,
+    'INDICATOR_HISTORY_SAVED_DELETION'                           => 39,
+    'INDICATOR_HISTORY_SAVED_INSERTION'                          => 38,
     'INDICATOR_IME'                                              => 32,
     'INDICATOR_IME_MAX'                                          => 35,
-    'INDICATOR_MAX'                                              => 35,
+    'INDICATOR_MAX'                                              => 43,
     'INDICS_MASK'                                                => 0xE0,
     'INDIC_BOX'                                                  => 6,
     'INDIC_COMPOSITIONTHICK'                                     => 14,
@@ -46,7 +64,7 @@ our %scimsg_dummyhash = (
     'INDIC_DIAGONAL'                                             => 3,
     'INDIC_DOTBOX'                                               => 12,
     'INDIC_DOTS'                                                 => 10,
-    'INDIC_EXPLORERLINK'                                         => 22,
+    'INDIC_EXPLORERLINK'                                         => 23,
     'INDIC_FULLBOX'                                              => 16,
     'INDIC_GRADIENT'                                             => 20,
     'INDIC_GRADIENTCENTRE'                                       => 21,
@@ -57,6 +75,7 @@ our %scimsg_dummyhash = (
     'INDIC_PLAIN'                                                => 0,
     'INDIC_POINT'                                                => 18,
     'INDIC_POINTCHARACTER'                                       => 19,
+    'INDIC_POINT_TOP'                                            => 22,
     'INDIC_ROUNDBOX'                                             => 7,
     'INDIC_SQUIGGLE'                                             => 1,
     'INDIC_SQUIGGLELOW'                                          => 11,
@@ -88,6 +107,7 @@ our %scimsg_dummyhash = (
     'SCI_ALLOCATE'                                               => 2446,
     'SCI_ALLOCATEEXTENDEDSTYLES'                                 => 2553,
     'SCI_ALLOCATELINECHARACTERINDEX'                             => 2711,
+    'SCI_ALLOCATELINES'                                          => 2089,
     'SCI_ALLOCATESUBSTYLES'                                      => 4020,
     'SCI_ANNOTATIONCLEARALL'                                     => 2547,
     'SCI_ANNOTATIONGETLINES'                                     => 2546,
@@ -117,6 +137,7 @@ our %scimsg_dummyhash = (
     'SCI_AUTOCGETMAXHEIGHT'                                      => 2211,
     'SCI_AUTOCGETMAXWIDTH'                                       => 2209,
     'SCI_AUTOCGETMULTI'                                          => 2637,
+    'SCI_AUTOCGETOPTIONS'                                        => 2639,
     'SCI_AUTOCGETORDER'                                          => 2661,
     'SCI_AUTOCGETSEPARATOR'                                      => 2107,
     'SCI_AUTOCGETTYPESEPARATOR'                                  => 2285,
@@ -132,6 +153,7 @@ our %scimsg_dummyhash = (
     'SCI_AUTOCSETMAXHEIGHT'                                      => 2210,
     'SCI_AUTOCSETMAXWIDTH'                                       => 2208,
     'SCI_AUTOCSETMULTI'                                          => 2636,
+    'SCI_AUTOCSETOPTIONS'                                        => 2638,
     'SCI_AUTOCSETORDER'                                          => 2660,
     'SCI_AUTOCSETSEPARATOR'                                      => 2106,
     'SCI_AUTOCSETTYPESEPARATOR'                                  => 2286,
@@ -174,6 +196,7 @@ our %scimsg_dummyhash = (
     'SCI_CLEAR'                                                  => 2180,
     'SCI_CLEARALL'                                               => 2004,
     'SCI_CLEARALLCMDKEYS'                                        => 2072,
+    'SCI_CLEARALLREPRESENTATIONS'                                => 2770,
     'SCI_CLEARCMDKEY'                                            => 2071,
     'SCI_CLEARDOCUMENTSTYLE'                                     => 2005,
     'SCI_CLEARREGISTEREDIMAGES'                                  => 2408,
@@ -231,12 +254,14 @@ our %scimsg_dummyhash = (
     'SCI_FINDINDICATORHIDE'                                      => 2642,
     'SCI_FINDINDICATORSHOW'                                      => 2640,
     'SCI_FINDTEXT'                                               => 2150,
+    'SCI_FINDTEXTFULL'                                           => 2196,
     'SCI_FOLDALL'                                                => 2662,
     'SCI_FOLDCHILDREN'                                           => 2238,
     'SCI_FOLDDISPLAYTEXTGETSTYLE'                                => 2707,
     'SCI_FOLDDISPLAYTEXTSETSTYLE'                                => 2701,
     'SCI_FOLDLINE'                                               => 2237,
     'SCI_FORMATRANGE'                                            => 2151,
+    'SCI_FORMATRANGEFULL'                                        => 2777,
     'SCI_FORMFEED'                                               => 2330,
     'SCI_FREESUBSTYLES'                                          => 4023,
     'SCI_GETACCESSIBILITY'                                       => 2703,
@@ -256,12 +281,15 @@ our %scimsg_dummyhash = (
     'SCI_GETCARETLINEBACK'                                       => 2097,
     'SCI_GETCARETLINEBACKALPHA'                                  => 2471,
     'SCI_GETCARETLINEFRAME'                                      => 2704,
+    'SCI_GETCARETLINEHIGHLIGHTSUBLINE'                           => 2773,
+    'SCI_GETCARETLINELAYER'                                      => 2764,
     'SCI_GETCARETLINEVISIBLE'                                    => 2095,
     'SCI_GETCARETLINEVISIBLEALWAYS'                              => 2654,
     'SCI_GETCARETPERIOD'                                         => 2075,
     'SCI_GETCARETSTICKY'                                         => 2457,
     'SCI_GETCARETSTYLE'                                          => 2513,
     'SCI_GETCARETWIDTH'                                          => 2189,
+    'SCI_GETCHANGEHISTORY'                                       => 2781,
     'SCI_GETCHARACTERCATEGORYOPTIMIZATION'                       => 2721,
     'SCI_GETCHARACTERPOINTER'                                    => 2520,
     'SCI_GETCHARAT'                                              => 2007,
@@ -275,11 +303,16 @@ our %scimsg_dummyhash = (
     'SCI_GETDEFAULTFOLDDISPLAYTEXT'                              => 2723,
     'SCI_GETDIRECTFUNCTION'                                      => 2184,
     'SCI_GETDIRECTPOINTER'                                       => 2185,
+    'SCI_GETDIRECTSTATUSFUNCTION'                                => 2772,
     'SCI_GETDOCPOINTER'                                          => 2357,
     'SCI_GETDOCUMENTOPTIONS'                                     => 2379,
     'SCI_GETEDGECOLOUR'                                          => 2364,
     'SCI_GETEDGECOLUMN'                                          => 2360,
     'SCI_GETEDGEMODE'                                            => 2362,
+    'SCI_GETELEMENTALLOWSTRANSLUCENT'                            => 2757,
+    'SCI_GETELEMENTBASECOLOUR'                                   => 2758,
+    'SCI_GETELEMENTCOLOUR'                                       => 2754,
+    'SCI_GETELEMENTISSET'                                        => 2756,
     'SCI_GETENDATLASTLINE'                                       => 2278,
     'SCI_GETENDSTYLED'                                           => 2028,
     'SCI_GETEOLMODE'                                             => 2030,
@@ -290,6 +323,7 @@ our %scimsg_dummyhash = (
     'SCI_GETFOLDEXPANDED'                                        => 2230,
     'SCI_GETFOLDLEVEL'                                           => 2223,
     'SCI_GETFOLDPARENT'                                          => 2225,
+    'SCI_GETFONTLOCALE'                                          => 2761,
     'SCI_GETFONTQUALITY'                                         => 2612,
     'SCI_GETGAPPOSITION'                                         => 2644,
     'SCI_GETHIGHLIGHTGUIDE'                                      => 2135,
@@ -308,6 +342,7 @@ our %scimsg_dummyhash = (
     'SCI_GETKEYSUNICODE'                                         => 2522,
     'SCI_GETLASTCHILD'                                           => 2224,
     'SCI_GETLAYOUTCACHE'                                         => 2273,
+    'SCI_GETLAYOUTTHREADS'                                       => 2776,
     'SCI_GETLENGTH'                                              => 2006,
     'SCI_GETLEXER'                                               => 4002,
     'SCI_GETLEXERLANGUAGE'                                       => 4012,
@@ -368,12 +403,16 @@ our %scimsg_dummyhash = (
     'SCI_GETRECTANGULARSELECTIONCARETVIRTUALSPACE'               => 2593,
     'SCI_GETRECTANGULARSELECTIONMODIFIER'                        => 2599,
     'SCI_GETREPRESENTATION'                                      => 2666,
+    'SCI_GETREPRESENTATIONAPPEARANCE'                            => 2767,
+    'SCI_GETREPRESENTATIONCOLOUR'                                => 2769,
     'SCI_GETSCROLLWIDTH'                                         => 2275,
     'SCI_GETSCROLLWIDTHTRACKING'                                 => 2517,
     'SCI_GETSEARCHFLAGS'                                         => 2199,
     'SCI_GETSELALPHA'                                            => 2477,
     'SCI_GETSELECTIONEMPTY'                                      => 2650,
     'SCI_GETSELECTIONEND'                                        => 2145,
+    'SCI_GETSELECTIONHIDDEN'                                     => 2088,
+    'SCI_GETSELECTIONLAYER'                                      => 2762,
     'SCI_GETSELECTIONMODE'                                       => 2423,
     'SCI_GETSELECTIONNANCHOR'                                    => 2579,
     'SCI_GETSELECTIONNANCHORVIRTUALSPACE'                        => 2583,
@@ -392,7 +431,9 @@ our %scimsg_dummyhash = (
     'SCI_GETSTYLEBITS'                                           => 2091,
     'SCI_GETSTYLEBITSNEEDED'                                     => 4011,
     'SCI_GETSTYLEDTEXT'                                          => 2015,
+    'SCI_GETSTYLEDTEXTFULL'                                      => 2778,
     'SCI_GETSTYLEFROMSUBSTYLE'                                   => 4027,
+    'SCI_GETSTYLEINDEXAT'                                        => 2038,
     'SCI_GETSUBSTYLEBASES'                                       => 4026,
     'SCI_GETSUBSTYLESLENGTH'                                     => 4022,
     'SCI_GETSUBSTYLESSTART'                                      => 4021,
@@ -410,6 +451,7 @@ our %scimsg_dummyhash = (
     'SCI_GETTEXT'                                                => 2182,
     'SCI_GETTEXTLENGTH'                                          => 2183,
     'SCI_GETTEXTRANGE'                                           => 2162,
+    'SCI_GETTEXTRANGEFULL'                                       => 2039,
     'SCI_GETTWOPHASEDRAW'                                        => 2283,
     'SCI_GETUNDOCOLLECTION'                                      => 2019,
     'SCI_GETUSETABS'                                             => 2125,
@@ -452,6 +494,7 @@ our %scimsg_dummyhash = (
     'SCI_INDICGETHOVERFORE'                                      => 2683,
     'SCI_INDICGETHOVERSTYLE'                                     => 2681,
     'SCI_INDICGETOUTLINEALPHA'                                   => 2559,
+    'SCI_INDICGETSTROKEWIDTH'                                    => 2752,
     'SCI_INDICGETSTYLE'                                          => 2081,
     'SCI_INDICGETUNDER'                                          => 2511,
     'SCI_INDICSETALPHA'                                          => 2523,
@@ -460,6 +503,7 @@ our %scimsg_dummyhash = (
     'SCI_INDICSETHOVERFORE'                                      => 2682,
     'SCI_INDICSETHOVERSTYLE'                                     => 2680,
     'SCI_INDICSETOUTLINEALPHA'                                   => 2558,
+    'SCI_INDICSETSTROKEWIDTH'                                    => 2751,
     'SCI_INDICSETSTYLE'                                          => 2080,
     'SCI_INDICSETUNDER'                                          => 2510,
     'SCI_INSERTTEXT'                                             => 2003,
@@ -493,7 +537,6 @@ our %scimsg_dummyhash = (
     'SCI_LINEUP'                                                 => 2302,
     'SCI_LINEUPEXTEND'                                           => 2303,
     'SCI_LINEUPRECTEXTEND'                                       => 2427,
-    'SCI_LOADLEXERLIBRARY'                                       => 4007,
     'SCI_LOWERCASE'                                              => 2340,
     'SCI_MARGINGETSTYLE'                                         => 2533,
     'SCI_MARGINGETSTYLEOFFSET'                                   => 2538,
@@ -514,6 +557,7 @@ our %scimsg_dummyhash = (
     'SCI_MARKERDELETEHANDLE'                                     => 2018,
     'SCI_MARKERENABLEHIGHLIGHT'                                  => 2293,
     'SCI_MARKERGET'                                              => 2046,
+    'SCI_MARKERGETLAYER'                                         => 2734,
     'SCI_MARKERHANDLEFROMLINE'                                   => 2732,
     'SCI_MARKERLINEFROMHANDLE'                                   => 2017,
     'SCI_MARKERNEXT'                                             => 2047,
@@ -522,7 +566,12 @@ our %scimsg_dummyhash = (
     'SCI_MARKERSETALPHA'                                         => 2476,
     'SCI_MARKERSETBACK'                                          => 2042,
     'SCI_MARKERSETBACKSELECTED'                                  => 2292,
+    'SCI_MARKERSETBACKSELECTEDTRANSLUCENT'                       => 2296,
+    'SCI_MARKERSETBACKTRANSLUCENT'                               => 2295,
     'SCI_MARKERSETFORE'                                          => 2041,
+    'SCI_MARKERSETFORETRANSLUCENT'                               => 2294,
+    'SCI_MARKERSETLAYER'                                         => 2735,
+    'SCI_MARKERSETSTROKEWIDTH'                                   => 2297,
     'SCI_MARKERSYMBOLDEFINED'                                    => 2529,
     'SCI_MOVECARETINSIDEVIEW'                                    => 2401,
     'SCI_MOVESELECTEDLINESDOWN'                                  => 2621,
@@ -564,9 +613,12 @@ our %scimsg_dummyhash = (
     'SCI_RELEASEALLEXTENDEDSTYLES'                               => 2552,
     'SCI_RELEASEDOCUMENT'                                        => 2377,
     'SCI_RELEASELINECHARACTERINDEX'                              => 2712,
+    'SCI_REPLACERECTANGULAR'                                     => 2771,
     'SCI_REPLACESEL'                                             => 2170,
     'SCI_REPLACETARGET'                                          => 2194,
+    'SCI_REPLACETARGETMINIMAL'                                   => 2779,
     'SCI_REPLACETARGETRE'                                        => 2195,
+    'SCI_RESETELEMENTCOLOUR'                                     => 2755,
     'SCI_RGBAIMAGESETHEIGHT'                                     => 2625,
     'SCI_RGBAIMAGESETSCALE'                                      => 2651,
     'SCI_RGBAIMAGESETWIDTH'                                      => 2624,
@@ -599,12 +651,15 @@ our %scimsg_dummyhash = (
     'SCI_SETCARETLINEBACK'                                       => 2098,
     'SCI_SETCARETLINEBACKALPHA'                                  => 2470,
     'SCI_SETCARETLINEFRAME'                                      => 2705,
+    'SCI_SETCARETLINEHIGHLIGHTSUBLINE'                           => 2774,
+    'SCI_SETCARETLINELAYER'                                      => 2765,
     'SCI_SETCARETLINEVISIBLE'                                    => 2096,
     'SCI_SETCARETLINEVISIBLEALWAYS'                              => 2655,
     'SCI_SETCARETPERIOD'                                         => 2076,
     'SCI_SETCARETSTICKY'                                         => 2458,
     'SCI_SETCARETSTYLE'                                          => 2512,
     'SCI_SETCARETWIDTH'                                          => 2188,
+    'SCI_SETCHANGEHISTORY'                                       => 2780,
     'SCI_SETCHARACTERCATEGORYOPTIMIZATION'                       => 2720,
     'SCI_SETCHARSDEFAULT'                                        => 2444,
     'SCI_SETCODEPAGE'                                            => 2037,
@@ -617,6 +672,7 @@ our %scimsg_dummyhash = (
     'SCI_SETEDGECOLOUR'                                          => 2365,
     'SCI_SETEDGECOLUMN'                                          => 2361,
     'SCI_SETEDGEMODE'                                            => 2363,
+    'SCI_SETELEMENTCOLOUR'                                       => 2753,
     'SCI_SETEMPTYSELECTION'                                      => 2556,
     'SCI_SETENDATLASTLINE'                                       => 2277,
     'SCI_SETEOLMODE'                                             => 2031,
@@ -629,6 +685,7 @@ our %scimsg_dummyhash = (
     'SCI_SETFOLDLEVEL'                                           => 2222,
     'SCI_SETFOLDMARGINCOLOUR'                                    => 2290,
     'SCI_SETFOLDMARGINHICOLOUR'                                  => 2291,
+    'SCI_SETFONTLOCALE'                                          => 2760,
     'SCI_SETFONTQUALITY'                                         => 2611,
     'SCI_SETHIGHLIGHTGUIDE'                                      => 2134,
     'SCI_SETHOTSPOTACTIVEBACK'                                   => 2411,
@@ -648,9 +705,8 @@ our %scimsg_dummyhash = (
     'SCI_SETKEYSUNICODE'                                         => 2521,
     'SCI_SETKEYWORDS'                                            => 4005,
     'SCI_SETLAYOUTCACHE'                                         => 2272,
+    'SCI_SETLAYOUTTHREADS'                                       => 2775,
     'SCI_SETLENGTHFORENCODE'                                     => 2448,
-    'SCI_SETLEXER'                                               => 4001,
-    'SCI_SETLEXERLANGUAGE'                                       => 4006,
     'SCI_SETLINEENDTYPESALLOWED'                                 => 2656,
     'SCI_SETLINEINDENTATION'                                     => 2126,
     'SCI_SETLINESTATE'                                           => 2092,
@@ -688,6 +744,8 @@ our %scimsg_dummyhash = (
     'SCI_SETRECTANGULARSELECTIONCARETVIRTUALSPACE'               => 2592,
     'SCI_SETRECTANGULARSELECTIONMODIFIER'                        => 2598,
     'SCI_SETREPRESENTATION'                                      => 2665,
+    'SCI_SETREPRESENTATIONAPPEARANCE'                            => 2766,
+    'SCI_SETREPRESENTATIONCOLOUR'                                => 2768,
     'SCI_SETSAVEPOINT'                                           => 2014,
     'SCI_SETSCROLLWIDTH'                                         => 2274,
     'SCI_SETSCROLLWIDTHTRACKING'                                 => 2516,
@@ -697,6 +755,7 @@ our %scimsg_dummyhash = (
     'SCI_SETSELBACK'                                             => 2068,
     'SCI_SETSELECTION'                                           => 2572,
     'SCI_SETSELECTIONEND'                                        => 2144,
+    'SCI_SETSELECTIONLAYER'                                      => 2763,
     'SCI_SETSELECTIONMODE'                                       => 2422,
     'SCI_SETSELECTIONNANCHOR'                                    => 2578,
     'SCI_SETSELECTIONNANCHORVIRTUALSPACE'                        => 2582,
@@ -759,10 +818,12 @@ our %scimsg_dummyhash = (
     'SCI_STYLEGETCASE'                                           => 2489,
     'SCI_STYLEGETCHANGEABLE'                                     => 2492,
     'SCI_STYLEGETCHARACTERSET'                                   => 2490,
+    'SCI_STYLEGETCHECKMONOSPACED'                                => 2255,
     'SCI_STYLEGETEOLFILLED'                                      => 2487,
     'SCI_STYLEGETFONT'                                           => 2486,
     'SCI_STYLEGETFORE'                                           => 2481,
     'SCI_STYLEGETHOTSPOT'                                        => 2493,
+    'SCI_STYLEGETINVISIBLEREPRESENTATION'                        => 2257,
     'SCI_STYLEGETITALIC'                                         => 2484,
     'SCI_STYLEGETSIZE'                                           => 2485,
     'SCI_STYLEGETSIZEFRACTIONAL'                                 => 2062,
@@ -775,16 +836,19 @@ our %scimsg_dummyhash = (
     'SCI_STYLESETCASE'                                           => 2060,
     'SCI_STYLESETCHANGEABLE'                                     => 2099,
     'SCI_STYLESETCHARACTERSET'                                   => 2066,
+    'SCI_STYLESETCHECKMONOSPACED'                                => 2254,
     'SCI_STYLESETEOLFILLED'                                      => 2057,
     'SCI_STYLESETFONT'                                           => 2056,
     'SCI_STYLESETFORE'                                           => 2051,
     'SCI_STYLESETHOTSPOT'                                        => 2409,
+    'SCI_STYLESETINVISIBLEREPRESENTATION'                        => 2256,
     'SCI_STYLESETITALIC'                                         => 2054,
     'SCI_STYLESETSIZE'                                           => 2055,
     'SCI_STYLESETSIZEFRACTIONAL'                                 => 2061,
     'SCI_STYLESETUNDERLINE'                                      => 2059,
     'SCI_STYLESETVISIBLE'                                        => 2074,
     'SCI_STYLESETWEIGHT'                                         => 2063,
+    'SCI_SUPPORTSFEATURE'                                        => 2750,
     'SCI_SWAPMAINANCHORCARET'                                    => 2607,
     'SCI_TAB'                                                    => 2327,
     'SCI_TAGSOFSTYLE'                                            => 4031,
@@ -880,7 +944,6 @@ our %scimsg_dummyhash = (
     'SCN_PAINTED'                                                => 2013,
     'SCN_SAVEPOINTLEFT'                                          => 2003,
     'SCN_SAVEPOINTREACHED'                                       => 2002,
-    'SCN_SCROLLED'                                               => 2080,
     'SCN_STYLENEEDED'                                            => 2000,
     'SCN_UPDATEUI'                                               => 2007,
     'SCN_URIDROPPED'                                             => 2015,
@@ -902,12 +965,16 @@ our %scimsg_dummyhash = (
     'SC_AC_DOUBLECLICK'                                          => 2,
     'SC_AC_FILLUP'                                               => 1,
     'SC_AC_NEWLINE'                                              => 4,
+    'SC_AC_SINGLE_CHOICE'                                        => 6,
     'SC_AC_TAB'                                                  => 3,
     'SC_ALPHA_NOALPHA'                                           => 256,
     'SC_ALPHA_OPAQUE'                                            => 255,
     'SC_ALPHA_TRANSPARENT'                                       => 0,
+    'SC_AUTOCOMPLETE_FIXED_SIZE'                                 => 1,
+    'SC_AUTOCOMPLETE_NORMAL'                                     => 0,
     'SC_AUTOMATICFOLD_CHANGE'                                    => 0x0004,
     'SC_AUTOMATICFOLD_CLICK'                                     => 0x0002,
+    'SC_AUTOMATICFOLD_NONE'                                      => 0x0000,
     'SC_AUTOMATICFOLD_SHOW'                                      => 0x0001,
     'SC_BIDIRECTIONAL_DISABLED'                                  => 0,
     'SC_BIDIRECTIONAL_L2R'                                       => 1,
@@ -925,6 +992,10 @@ our %scimsg_dummyhash = (
     'SC_CASE_LOWER'                                              => 2,
     'SC_CASE_MIXED'                                              => 0,
     'SC_CASE_UPPER'                                              => 1,
+    'SC_CHANGE_HISTORY_DISABLED'                                 => 0,
+    'SC_CHANGE_HISTORY_ENABLED'                                  => 1,
+    'SC_CHANGE_HISTORY_INDICATORS'                               => 4,
+    'SC_CHANGE_HISTORY_MARKERS'                                  => 2,
     'SC_CHARACTERSOURCE_DIRECT_INPUT'                            => 0,
     'SC_CHARACTERSOURCE_IME_RESULT'                              => 2,
     'SC_CHARACTERSOURCE_TENTATIVE_INPUT'                         => 1,
@@ -963,10 +1034,32 @@ our %scimsg_dummyhash = (
     'SC_EFF_QUALITY_LCD_OPTIMIZED'                               => 3,
     'SC_EFF_QUALITY_MASK'                                        => 0xF,
     'SC_EFF_QUALITY_NON_ANTIALIASED'                             => 1,
+    'SC_ELEMENT_CARET'                                           => 40,
+    'SC_ELEMENT_CARET_ADDITIONAL'                                => 41,
+    'SC_ELEMENT_CARET_LINE_BACK'                                 => 50,
+    'SC_ELEMENT_FOLD_LINE'                                       => 80,
+    'SC_ELEMENT_HIDDEN_LINE'                                     => 81,
+    'SC_ELEMENT_HOT_SPOT_ACTIVE'                                 => 70,
+    'SC_ELEMENT_HOT_SPOT_ACTIVE_BACK'                            => 71,
+    'SC_ELEMENT_LIST'                                            => 0,
+    'SC_ELEMENT_LIST_BACK'                                       => 1,
+    'SC_ELEMENT_LIST_SELECTED'                                   => 2,
+    'SC_ELEMENT_LIST_SELECTED_BACK'                              => 3,
+    'SC_ELEMENT_SELECTION_ADDITIONAL_BACK'                       => 13,
+    'SC_ELEMENT_SELECTION_ADDITIONAL_TEXT'                       => 12,
+    'SC_ELEMENT_SELECTION_BACK'                                  => 11,
+    'SC_ELEMENT_SELECTION_INACTIVE_BACK'                         => 17,
+    'SC_ELEMENT_SELECTION_INACTIVE_TEXT'                         => 16,
+    'SC_ELEMENT_SELECTION_SECONDARY_BACK'                        => 15,
+    'SC_ELEMENT_SELECTION_SECONDARY_TEXT'                        => 14,
+    'SC_ELEMENT_SELECTION_TEXT'                                  => 10,
+    'SC_ELEMENT_WHITE_SPACE'                                     => 60,
+    'SC_ELEMENT_WHITE_SPACE_BACK'                                => 61,
     'SC_EOL_CR'                                                  => 1,
     'SC_EOL_CRLF'                                                => 0,
     'SC_EOL_LF'                                                  => 2,
     'SC_FOLDACTION_CONTRACT'                                     => 0,
+    'SC_FOLDACTION_CONTRACT_EVERY_LEVEL'                         => 4,
     'SC_FOLDACTION_EXPAND'                                       => 1,
     'SC_FOLDACTION_TOGGLE'                                       => 2,
     'SC_FOLDDISPLAYTEXT_BOXED'                                   => 2,
@@ -978,8 +1071,10 @@ our %scimsg_dummyhash = (
     'SC_FOLDFLAG_LINEBEFORE_CONTRACTED'                          => 0x0004,
     'SC_FOLDFLAG_LINEBEFORE_EXPANDED'                            => 0x0002,
     'SC_FOLDFLAG_LINESTATE'                                      => 0x0080,
+    'SC_FOLDFLAG_NONE'                                           => 0x0000,
     'SC_FOLDLEVELBASE'                                           => 0x400,
     'SC_FOLDLEVELHEADERFLAG'                                     => 0x2000,
+    'SC_FOLDLEVELNONE'                                           => 0x0,
     'SC_FOLDLEVELNUMBERMASK'                                     => 0x0FFF,
     'SC_FOLDLEVELWHITEFLAG'                                      => 0x1000,
     'SC_FONT_SIZE_MULTIPLIER'                                    => 100,
@@ -989,6 +1084,7 @@ our %scimsg_dummyhash = (
     'SC_IDLESTYLING_TOVISIBLE'                                   => 1,
     'SC_IME_INLINE'                                              => 1,
     'SC_IME_WINDOWED'                                            => 0,
+    'SC_INDICFLAG_NONE'                                          => 0,
     'SC_INDICFLAG_VALUEFORE'                                     => 1,
     'SC_INDICVALUEBIT'                                           => 0x1000000,
     'SC_INDICVALUEMASK'                                          => 0xFFFFFF,
@@ -997,6 +1093,9 @@ our %scimsg_dummyhash = (
     'SC_IV_NONE'                                                 => 0,
     'SC_IV_REAL'                                                 => 1,
     'SC_LASTSTEPINUNDOREDO'                                      => 0x100,
+    'SC_LAYER_BASE'                                              => 0,
+    'SC_LAYER_OVER_TEXT'                                         => 2,
+    'SC_LAYER_UNDER_TEXT'                                        => 1,
     'SC_LINECHARACTERINDEX_NONE'                                 => 0,
     'SC_LINECHARACTERINDEX_UTF16'                                => 2,
     'SC_LINECHARACTERINDEX_UTF32'                                => 1,
@@ -1018,11 +1117,16 @@ our %scimsg_dummyhash = (
     'SC_MARKNUM_FOLDEROPENMID'                                   => 26,
     'SC_MARKNUM_FOLDERSUB'                                       => 29,
     'SC_MARKNUM_FOLDERTAIL'                                      => 28,
+    'SC_MARKNUM_HISTORY_MODIFIED'                                => 23,
+    'SC_MARKNUM_HISTORY_REVERTED_TO_MODIFIED'                    => 24,
+    'SC_MARKNUM_HISTORY_REVERTED_TO_ORIGIN'                      => 21,
+    'SC_MARKNUM_HISTORY_SAVED'                                   => 22,
     'SC_MARK_ARROW'                                              => 2,
     'SC_MARK_ARROWDOWN'                                          => 6,
     'SC_MARK_ARROWS'                                             => 24,
     'SC_MARK_AVAILABLE'                                          => 28,
     'SC_MARK_BACKGROUND'                                         => 22,
+    'SC_MARK_BAR'                                                => 33,
     'SC_MARK_BOOKMARK'                                           => 31,
     'SC_MARK_BOXMINUS'                                           => 14,
     'SC_MARK_BOXMINUSCONNECTED'                                  => 15,
@@ -1096,6 +1200,9 @@ our %scimsg_dummyhash = (
     'SC_PRINT_INVERTLIGHT'                                       => 1,
     'SC_PRINT_NORMAL'                                            => 0,
     'SC_PRINT_SCREENCOLOURS'                                     => 5,
+    'SC_REPRESENTATION_BLOB'                                     => 1,
+    'SC_REPRESENTATION_COLOUR'                                   => 0x10,
+    'SC_REPRESENTATION_PLAIN'                                    => 0,
     'SC_SEARCHRESULT_LINEBUFFERMAXLENGTH'                        => 2048,
     'SC_SEL_LINES'                                               => 2,
     'SC_SEL_RECTANGLE'                                           => 1,
@@ -1107,6 +1214,12 @@ our %scimsg_dummyhash = (
     'SC_STATUS_OK'                                               => 0,
     'SC_STATUS_WARN_REGEX'                                       => 1001,
     'SC_STATUS_WARN_START'                                       => 1000,
+    'SC_SUPPORTS_FRACTIONAL_STROKE_WIDTH'                        => 2,
+    'SC_SUPPORTS_LINE_DRAWS_FINAL'                               => 0,
+    'SC_SUPPORTS_PIXEL_DIVISIONS'                                => 1,
+    'SC_SUPPORTS_PIXEL_MODIFICATION'                             => 4,
+    'SC_SUPPORTS_THREAD_SAFE_MEASURE_WIDTHS'                     => 5,
+    'SC_SUPPORTS_TRANSLUCENT_STROKE'                             => 3,
     'SC_TECHNOLOGY_DEFAULT'                                      => 0,
     'SC_TECHNOLOGY_DIRECTWRITE'                                  => 1,
     'SC_TECHNOLOGY_DIRECTWRITEDC'                                => 3,
@@ -1117,6 +1230,7 @@ our %scimsg_dummyhash = (
     'SC_TYPE_STRING'                                             => 2,
     'SC_UPDATE_CONTENT'                                          => 0x1,
     'SC_UPDATE_H_SCROLL'                                         => 0x8,
+    'SC_UPDATE_NONE'                                             => 0x0,
     'SC_UPDATE_SELECTION'                                        => 0x2,
     'SC_UPDATE_V_SCROLL'                                         => 0x4,
     'SC_WEIGHT_BOLD'                                             => 700,
