@@ -68,7 +68,7 @@
 //10  Rename...
 //11  Close
 //12  Close All
-//13  Close More
+//13  Close Multiple Documents
 //14  Move to Recycle Bin
 //15  --------
 //16  Load Session...
@@ -170,11 +170,14 @@
     #define    IDM_EDIT_INSERT_DATETIME_CUSTOMIZED              (IDM_EDIT + 86)
     #define    IDM_EDIT_COPY_ALL_NAMES                          (IDM_EDIT + 87)
     #define    IDM_EDIT_COPY_ALL_PATHS                          (IDM_EDIT + 88)
+    #define    IDM_EDIT_BEGINENDSELECT_COLUMNMODE               (IDM_EDIT + 89)
 
     #define    IDM_EDIT_AUTOCOMPLETE                            (50000 + 0)
     #define    IDM_EDIT_AUTOCOMPLETE_CURRENTFILE                (50000 + 1)
     #define    IDM_EDIT_FUNCCALLTIP                             (50000 + 2)
     #define    IDM_EDIT_AUTOCOMPLETE_PATH                       (50000 + 6)
+    #define    IDM_EDIT_FUNCCALLTIP_PREVIOUS                    (50000 + 10)
+    #define    IDM_EDIT_FUNCCALLTIP_NEXT                        (50000 + 11)
 
     
 #define    IDM_SEARCH    (IDM + 3000)
@@ -265,7 +268,7 @@
     #define    IDM_VIEW_DRAWTABBAR_TOPBAR         (IDM_VIEW + 7)
     #define    IDM_VIEW_DRAWTABBAR_INACIVETAB     (IDM_VIEW + 8) 
     #define    IDM_VIEW_POSTIT                    (IDM_VIEW + 9)
-    #define    IDM_VIEW_TOGGLE_FOLDALL            (IDM_VIEW + 10)
+    #define    IDM_VIEW_FOLDALL                   (IDM_VIEW + 10)
     #define    IDM_VIEW_DISTRACTIONFREE           (IDM_VIEW + 11)
     #define    IDM_VIEW_LINENUMBER                (IDM_VIEW + 12)
     #define    IDM_VIEW_SYMBOLMARGIN              (IDM_VIEW + 13)
@@ -284,7 +287,7 @@
     #define    IDM_VIEW_EOL                       (IDM_VIEW + 26)
     #define    IDM_VIEW_TOOLBAR_REDUCE_SET2       (IDM_VIEW + 27)
     #define    IDM_VIEW_TOOLBAR_ENLARGE_SET2      (IDM_VIEW + 28)
-    #define    IDM_VIEW_TOGGLE_UNFOLDALL          (IDM_VIEW + 29)
+    #define    IDM_VIEW_UNFOLDALL                 (IDM_VIEW + 29)
     #define    IDM_VIEW_FOLD_CURRENT              (IDM_VIEW + 30)
     #define    IDM_VIEW_UNFOLD_CURRENT            (IDM_VIEW + 31)
     #define    IDM_VIEW_FULLSCREENTOGGLE          (IDM_VIEW + 32)
@@ -300,7 +303,7 @@
     #define    IDM_VIEW_HIDELINES                 (IDM_VIEW + 42)
     #define    IDM_VIEW_DRAWTABBAR_VERTICAL       (IDM_VIEW + 43)
     #define    IDM_VIEW_DRAWTABBAR_MULTILINE      (IDM_VIEW + 44)
-    #define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
+    //#define    IDM_VIEW_DOCCHANGEMARGIN           (IDM_VIEW + 45)
     #define    IDM_VIEW_LWDEF                     (IDM_VIEW + 46)
     #define    IDM_VIEW_LWALIGN                   (IDM_VIEW + 47)
     #define    IDM_VIEW_LWINDENT                  (IDM_VIEW + 48)
@@ -365,6 +368,16 @@
     #define    IDM_VIEW_SWITCHTO_FUNC_LIST        (IDM_VIEW + 108)
     #define    IDM_VIEW_SWITCHTO_DOCLIST          (IDM_VIEW + 109)
 
+    #define    IDM_VIEW_TAB_COLOUR_NONE           (IDM_VIEW + 110)
+    #define    IDM_VIEW_TAB_COLOUR_1              (IDM_VIEW + 111)
+    #define    IDM_VIEW_TAB_COLOUR_2              (IDM_VIEW + 112)
+    #define    IDM_VIEW_TAB_COLOUR_3              (IDM_VIEW + 113)
+    #define    IDM_VIEW_TAB_COLOUR_4              (IDM_VIEW + 114)
+    #define    IDM_VIEW_TAB_COLOUR_5              (IDM_VIEW + 115)
+
+    #define    IDM_VIEW_NPC                       (IDM_VIEW + 130)
+    #define    IDM_VIEW_NPC_CCUNIEOL              (IDM_VIEW + 131)
+
     #define    IDM_VIEW_GOTO_ANOTHER_VIEW        10001
     #define    IDM_VIEW_CLONE_TO_ANOTHER_VIEW    10002
     #define    IDM_VIEW_GOTO_NEW_INSTANCE        10003
@@ -525,7 +538,11 @@
     #define    IDM_LANG_TXT2TAGS           (IDM_LANG + 82)
     #define    IDM_LANG_VISUALPROLOG       (IDM_LANG + 83)
     #define    IDM_LANG_TYPESCRIPT         (IDM_LANG + 84)
-
+    #define    IDM_LANG_JSON5              (IDM_LANG + 85)
+    #define    IDM_LANG_MSSQL              (IDM_LANG + 86)
+    #define    IDM_LANG_GDSCRIPT           (IDM_LANG + 87)
+    #define    IDM_LANG_HOLLYWOOD          (IDM_LANG + 88)
+    
     #define    IDM_LANG_EXTERNAL           (IDM_LANG + 165)
     #define    IDM_LANG_EXTERNAL_LIMIT     (IDM_LANG + 179)
 
@@ -597,6 +614,10 @@
     #define  IDM_WINDOW_SORT_FS_ASC	(IDR_WINDOWS_MENU + 8)
     #define  IDM_WINDOW_SORT_FS_DSC	(IDR_WINDOWS_MENU + 9)
     #define  IDM_WINDOW_MRU_FIRST 	(IDR_WINDOWS_MENU + 20)
-    #define  IDM_WINDOW_MRU_LIMIT 	(IDR_WINDOWS_MENU + 29)
+    #define  IDM_WINDOW_MRU_LIMIT 	(IDR_WINDOWS_MENU + 59)
     #define  IDM_WINDOW_COPY_NAME 	(IDM_WINDOW_MRU_LIMIT + 1)
     #define  IDM_WINDOW_COPY_PATH 	(IDM_WINDOW_MRU_LIMIT + 2)
+
+#define IDR_DROPLIST_MENU 14000
+    #define    IDM_DROPLIST_LIST           (IDR_DROPLIST_MENU + 1)
+    #define    IDM_DROPLIST_MRU_FIRST      (IDR_DROPLIST_MENU + 20)
